@@ -18,20 +18,20 @@ from ._lib import *
 from ._version import __version__
 
 __all__ = [
-    'BinaryType',
-    'ConjureBeanType',
-    'ConjureDecoder',
-    'ConjureEncoder',
-    'ConjureEnumType',
-    'ConjureFieldDefinition',
-    'ConjureType',
-    'ConjureUnionType',
-    'DecodableType',
-    'DictType',
-    'ListType',
-    'OptionalType',
-    'RequestsClient',
-    'Service',
-    'ServiceConfiguration',
-    'SslConfiguration',
+    "BinaryType",
+    "ConjureBeanType",
+    "ConjureDecoder",
+    "ConjureEncoder",
+    "ConjureEnumType",
+    "ConjureFieldDefinition",
+    "ConjureType",
+    "ConjureUnionType",
+    "DecodableType",
+    "DictType",
+    "ListType",
+    "OptionalType",
+    "RequestsClient",
+    "Service",
+    "ServiceConfiguration",
+    "SslConfiguration",
 ]
